import Option, { OptionConfig } from './Option';
interface CommandArg {
    required: boolean;
    value: string;
    variadic: boolean;
}
interface HelpConfig {
    bin: string;
    subCommands?: Command[];
    versionNumber?: string;
    globalOptions?: Option[];
}
interface HelpSection {
    title?: string;
    body: string;
}
interface CommandConfig {
    allowUnknownOptions?: boolean;
}
declare type HelpCallback = (sections: HelpSection[]) => void;
export default class Command {
    rawName: string;
    description: string;
    options: Option[];
    aliasNames: string[];
    name: string;
    args: CommandArg[];
    commandAction?: (...args: any[]) => any;
    usageText?: string;
    versionNumber?: string;
    examples: string[];
    config: CommandConfig;
    helpCallback?: HelpCallback;
    constructor(rawName: string, description: string);
    usage(text: string): this;
    allowUnknownOptions(): this;
    version(version: string): this;
    example(text: string): this;
    /**
     * Add a option for this command
     * @param rawName Raw option name(s)
     * @param description Option description
     * @param config Option config
     */
    option(rawName: string, description: string, config?: OptionConfig): this;
    alias(name: string): this;
    action(callback: (...args: any[]) => any): this;
    /**
     * Check if a command name is matched by this command
     * @param name Command name
     */
    isMatched(name: string): boolean;
    readonly isDefaultCommand: boolean;
    /**
     * Check if an option is registered in this command
     * @param name Option name
     */
    hasOption(name: string): Option | undefined;
    outputHelp(config: HelpConfig): void;
    outputVersion(bin: string): this;
    checkUnknownOptions(options: {
        [k: string]: any;
    }, globalCommand: Command): boolean;
}
export { HelpCallback };
