/// <reference types="minimist" />
/// <reference types="node" />
import { EventEmitter } from 'events';
import { Opts as MinimostOpts } from 'minimost';
import Command, { HelpCallback } from './Command';
import { OptionConfig } from './Option';
interface ParsedArgv {
    args: string[];
    options: {
        [k: string]: any;
    };
}
declare class CAC extends EventEmitter {
    bin: string;
    commands: Command[];
    globalCommand: Command;
    matchedCommand: Command;
    /**
     * Raw CLI arguments
     */
    rawArgs: string[];
    /**
     * Parsed CLI arguments
     */
    args: string[];
    /**
     * Parsed CLI options
     */
    options: {
        [k: string]: any;
    };
    constructor();
    usage(text: string): this;
    command(rawName: string, description: string): Command;
    option(rawName: string, description: string, config?: OptionConfig): this;
    help(callback?: HelpCallback): this;
    version(version: string): this;
    /**
     * Add a global example
     * @param example
     */
    example(example: string): this;
    outputHelp(): this;
    outputVersion(): this;
    parse(argv?: string[]): ParsedArgv;
    minimost(argv: string[], minimostOptions: MinimostOpts): {
        args: string[];
        options: {
            [k: string]: any;
        };
    };
    runCommandAction(command: Command, globalCommand: Command, { args, options }: ParsedArgv): any;
}
declare const cac: () => CAC;
export default cac;
